==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/InteractionforemailCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Interactionforemail;
import microsoft.dynamics.crm.entity.request.ActivitypointerRequest;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.InteractionforemailRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class InteractionforemailCollectionRequest extends CollectionPageEntityRequest<Interactionforemail, InteractionforemailRequest>{

    protected ContextPath contextPath;

    public InteractionforemailCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Interactionforemail.class, cp -> new InteractionforemailRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public ActivitypointerCollectionRequest new_interactionforemail_ActivityPointers() {
        return new ActivitypointerCollectionRequest(contextPath.addSegment("new_interactionforemail_ActivityPointers"), Optional.empty());
    }

    public ActivitypointerRequest new_interactionforemail_ActivityPointers(String activityid) {
        return new ActivitypointerRequest(contextPath.addSegment("new_interactionforemail_ActivityPointers").addKeys(new NameValue(activityid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest new_interactionforemail_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("new_interactionforemail_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest new_interactionforemail_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("new_interactionforemail_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/InteractionforemailCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Interactionforemail;
import microsoft.dynamics.crm.entity.request.ActivitypointerRequest;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.InteractionforemailRequest;

public class InteractionforemailCollectionRequest extends CollectionPageEntityRequest<Interactionforemail, InteractionforemailRequest>{

    protected ContextPath contextPath;

    public InteractionforemailCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Interactionforemail.class, cp -> new InteractionforemailRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public ActivitypointerCollectionRequest new_interactionforemail_ActivityPointers() {
        return new ActivitypointerCollectionRequest(contextPath.addSegment("new_interactionforemail_ActivityPointers"), Optional.empty());
    }

    public ActivitypointerRequest new_interactionforemail_ActivityPointers(String activityid) {
        return new ActivitypointerRequest(contextPath.addSegment("new_interactionforemail_ActivityPointers").addKeys(new NameValue(activityid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest new_interactionforemail_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("new_interactionforemail_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest new_interactionforemail_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("new_interactionforemail_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

}
